Changelog
=========

This document describes changes between each past release.

0.1.0 (2017-02-22)
------------------

Protocol is now version 0.1. See `API changelog`_.


**Initial version**

- Settings up the project based on kinto.core (#6)
- Add the subscription management API (#10)
- Add the channel registration management API (#12)
- Add the channel notification management API (#16)
- Handle empty payloads (#26)
- Handle duplication of subscriptions (#27)


.. _API changelog: https://webpush-channels-broadcasting/en/latest/api/
